from abrviz import Arbre, Noeud


a = Arbre()
liste = [Noeud(i) for i in [3, 2, 1, 5, 4, 6]]
for i in liste:
    a.inserer(i)


Arbre.sortie(a.racine, "exemple1_0", "png")
Arbre.sortie(liste[1], "exemple1_1", "png")
a.supprimer(liste[0])
Arbre.sortie(a.racine, "exemple1_2", "png")



from abrviz import Arbre, Noeud
import random


liste = list(range(15))
random.shuffle(liste)

a = Arbre()
for e in liste:
    a.inserer(Noeud(e))

mon_noeud = a.racine
Arbre.sortie(mon_noeud, "exemple2_0", "png")
Arbre.sortie(mon_noeud.droit, "exemple2_1", "png")

if mon_noeud.gauche is not None:
    mon_noeud = mon_noeud.gauche
    Arbre.sortie(mon_noeud, "exemple2_2", "png")
